#
# spec file for package calf
#
# Copyright (c) 2020 Packman Team <packman@links2linux.de>
# Copyright (c) 2009 oc2pus <oc2pus@arcor.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/
#


Name:           calf
Version:        0.90.3
Release:        pm152.3.1
Summary:        A pack of audio effects and instruments plugins
License:        LGPL-2.1-or-later AND GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            http://calf-studio-gear.org/
ExclusiveArch:  x86_64
Source:         https://github.com/calf-studio-gear/calf/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bash-completion
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(jack)
%if 0%{?suse_version} <= 1500
BuildRequires:  pkgconfig(lash-1.0)
%endif
BuildRequires:  pkgconfig(libglade-2.0)
BuildRequires:  pkgconfig(lv2)
Requires:       dssi
Requires:       jack
%if 0%{?suse_version} <= 1500
Requires:       lash
%endif

%description
Calf is a pack of audio plugins – effects and instruments, currently in
development. The goal is to create a set of plugins using decent algorithms
and parameter settings, available in a form which is compatible with as
many FOSS applications as possible.

%package -n lv2-%{name}
Summary:        Calf LV2 plugins
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       %{name} = %{version}

%description -n lv2-%{name}
Calf plugins for LV2.

%package        bash-completion
Summary:        Bash completion for %{name}
Group:          Productivity/Multimedia/Sound/Utilities
Supplements:    packageand(%{name}:bash)
Requires:       bash-completion
BuildArch:      noarch

%description    bash-completion
Bash command line completion support for %{name}.

%prep
%autosetup -p1

%build
sed -i 's|^\(docdir = \).*$|\1%{_docdir}/%{name}|' Makefile.am
sed -i '/^Version/d' %{name}.desktop*
autoreconf -fiv
%configure \
  --enable-static=no \
  --with-lv2-dir=%{_libdir}/lv2 \
  --enable-experimental \
  %ifarch %{ix86} x86_64
  --enable-sse
  %endif
%make_build

%install
%make_install

%fdupes %{buildroot}%{_datadir}
find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file -r %{name} AudioVideo Music

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%license COPYING
%doc AUTHORS ChangeLog README TODO
%doc %{_docdir}/%{name}/*
%{_bindir}/calfjackhost
%{_libdir}/%{name}/
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*
%{_mandir}/man?/*.?%{ext_man}

%files -n lv2-%{name}
%{_libdir}/lv2/

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Mon Nov  9 2020 Luigi Baldoni <aloisio@gmx.com>
- Don't require non-existent package on Tumbleweed
* Sat Sep  5 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.90.3
  * Bugfix release
- Fix Tumbleweed build
* Thu Jun 20 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.90.2.0
  * EQ30: Elliptic filters
  * Minor additions
  * Various fixes
- Dropped bba03b6080dc198f3513b5c29fe1ba4ff9e4aa59.patch
  (merged upstream)
* Fri Aug 31 2018 aloisio@gmx.com
- Update to version 0.90.1.0
  * Various bugfixes
  * Trayicon
  version 0.90.0.0
  * New plug-ins: Multiband Enhancer, Multi Spread, Vinyl
  * Calfjackhost: important values controlable from rack
  * Calfjackhost: custom names for rack devices
  * EQ8/EQ12: Q for high and low pass
  * EQ30: linked mode
  * VintageDelay/Pulsator: new timing settings
  * Vocoder: Upper and lower tilt, higher Q, band related Q
  * All plugins: input/output meters and knobs
  * Themeing capabilities
  * New Designs: Default, Flat Default, 0.0.19, Hybreed, Lost
    Wages, Midnight, Orange, Wood
  * Knobs with ticks for better orientation
  * Scales attached to level meters
  * Bash completion for effect names
  * More readme and documentation
  * Lots of fixes and minor improvements
- Dropped calf.gcc.patch (merged upstream)
* Fri Jan  1 2016 avvissu@yandex.ru
- Update to 0.0.60:
  * see: /usr/share/doc/packages/calf/ChangeLog
- Use pkgconfig(style)
- Add additional configuration options: --enable-{experimental,,sse}
* Mon Mar 16 2015 sor.alexei@meowr.ru
- Update to 0.0.19.
- Remove LADSPA plugins: dropped upstream.
- Remove calf-0.0.18.6-gcc47.diff: fixed upstream.
- Remove calf-rpmlintrc: no need for that.
- Spec cleanup.
* Sat May 19 2012 seife+obs@b1-systems.com
- fix build on > 12.1 (gcc4.7, remove %%suse_update_config)
* Mon Mar 14 2011 detlef@links2linux.de
- update to 0.0.18.6
* Thu Jun 11 2009 toni@links2linux.de
- update to 0.0.18.5
* Tue May  5 2009 toni@links2linux.de
- update to 0.0.18.4
* Sun Feb 15 2009 toni@links2linux.de
- update to 0.0.18.3
- added patch for ppc-build (thx to Manfred)
* Thu Jan 29 2009 toni@links2linux.de
- update to 0.0.18.2
* Wed Jan 28 2009 toni@links2linux.de
- update to 0.0.18.1
* Mon Jan 26 2009 toni@links2linux.de
- update to 0.0.18
* Sat Nov 29 2008 toni@links2linux.de
- update to 0.0.17
- A new Compressor plugin has been added. Most of the effects have new
  user interfaces. Live frequency response graphs have been added to
  Flanger, MultiChorus, and Filter GUIs. LV2 support has been improved.
  Bugfixes, clean-ups and new presets were included.
* Tue Nov 11 2008 toni@links2linux.de
- update to 0.0.16.3
* Thu Oct 30 2008 toni@links2linux.de
- update to 0.0.16.2
* Wed Oct 29 2008 toni@links2linux.de
- update to 0.0.16
* Wed Aug 20 2008 toni@links2linux.de
- update to 0.0.15
* Sat Jul  5 2008 toni@links2linux.de
- update to 0.0.14
* Thu May 29 2008 toni@links2linux.de
- update to 0.0.12
- added subpackage lv2-calf
* Wed Jan  2 2008 toni@links2linux.de
- update to 0.0.9
* Sun Dec 23 2007 toni@links2linux.de
- update to 0.0.8
* Sat Dec 22 2007 toni@links2linux.de
- update to 0.0.7
* Sat Dec 15 2007 toni@links2linux.de
- update to 0.0.6
- added dssi-calf subpackage
* Mon Dec  3 2007 toni@links2linux.de
- initial release 0.0.5a
